#ifndef NT2_INCLUDE_FUNCTIONS_ENUMERATE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ENUMERATE_HPP_INCLUDED

#include <nt2/swar/include/functions/enumerate.hpp>

#endif
